@@ -65,7 +65,6 @@ class Controllers:
             }
 
         self.enable_fake = not all([has_google, has_github])
-        self.models.enable_fake = self.enable_fake
 
     # Public methods
     def authenticate(self, token, next, callback_url, private_key):
@@ -262,6 +261,13 @@ class Controllers:
             token = self._get_token_from_userid(self.models.FAKE_USER_ID, private_key)
             next = self._update_next_url(next, token)
             ret[provider] = dict(url=next)
+        self.models.create_or_get_user(
+            self.models.FAKE_USER_ID,
+            self.models.FAKE_USER_RECORD['name'],
+            self.models.FAKE_USER_RECORD['username'],
+            self.models.FAKE_USER_RECORD['email'],
+            self.models.FAKE_USER_RECORD['avatar_url'],
+        )
         return ret
 
 
