@@ -38,13 +38,11 @@ class Models():
     _sql_engine = None
     _sql_session = None
 
-    enable_fake = False
-    FAKE_USER_ID = '___fake___user___'
     FAKE_USER_RECORD = dict(
-        provider_id=FAKE_USER_ID,
+        provider_id='__FAKE_USER__',
         username='fakeuser',
         name='Fakey McFakerson',
-        email='fakey@mcfakerson@com',
+        email='fakey@mcfakerson.com',
         avatar_url='https://www.gravatar.com/avatar/HASH',
         join_date=datetime.datetime.now()
     )
@@ -52,7 +50,7 @@ class Models():
     def __init__(self, connection_string='sqlite://'):
         self._sql_engine = create_engine(connection_string)
         Base.metadata.create_all(self._sql_engine)
-
+        self.FAKE_USER_ID = self.hash_email(self.FAKE_USER_RECORD['email'])
 
     @contextmanager
     def session_scope(self):
@@ -71,8 +69,6 @@ class Models():
             session.close()
 
     def get_user(self, id_):
-        if self.enable_fake and id_ == self.FAKE_USER_ID:
-            return self.FAKE_USER_RECORD
         with self.session_scope() as session:
             ret = session.query(User).filter_by(id=id_).first()
             if ret is not None:
